@@ -14,6 +14,22 @@ import os
 
 name = 'telegram_util'
 
+def cutCaptionHtml(text, limit):
+	lines = text.split('\n')
+	lines = [line.strip() for line in lines]
+	text = '\n'.join(lines)
+	for _ in range(5):
+		text = text.replace('\n\n\n', '\n\n')
+	if len(text) <= limit:
+		return text
+	lines = text.split('\n')
+	count = 0
+	for ind, line in enumerate(lines):
+		count += 1 + len(line)
+		if count > limit:
+			break
+	return '\n'.join(lines[:ind]).strip()
+
 def removeOldFiles(dirname, day = 3):
 	try:
 		os.listdir(dirname)
@@ -73,14 +89,17 @@ class AlbumResult(object):
 		self.rwid = '' # weibo status only retweet id
 		self.hash = ''
 		self.url = ''
+		self.cap_html_v2 = ''
 
 	def getParseMode(self):
+		if self.cap_html_v2:
+			return 'HTML'
 		if self.cap_html and 'weibo' not in self.url:
 			return 'HTML'
 		return 'Markdown'
 
 	def empty(self):
-		return (not self.imgs) and (not self.cap) and (not self.video)
+		return (not self.imgs) and (not self.cap) and (not self.video) and (not self.cap_html_v2)
 
 	def __str__(self):
 		return '\t'.join([k + ':' + str(v) for (k,v) in self.__dict__.items() if v])
@@ -140,7 +159,7 @@ def cleanFileName(name):
 		name = name.replace(x, '')
 	if name.split()[0][-1:] == ':':
 		name = name.replace(':', ' ', 1)
-	return name
+	return name[:50]
 
 def getSoup(url):
 	headers = {'Host':'telete.in',
@@ -368,10 +387,27 @@ def clearUrl(url):
 	for end_char in ['/?utm_source', '?mblogid', '&chksm=', 
 			'&amp;chksm=', '&scene=21']:
 		url = url.split(end_char)[0]
-	if not matchKey(url, 'id=', '/#/'):
+	if not matchKey(url, ['id=']):
 		url = url.split('#')[0]
 	if matchKey(url, ['weibo', 'thepaper', 'm.sohu']) and 'id=' not in url: 
 		url = url.split('?')[0]
 	if matchKey(url, ['/s/']):
 		url = url.split('?')[0]
-	return url.strip('/')
\ No newline at end of file
+	return url.strip('/')
+
+def getBasicLog(msg):
+	result = ['id: %d' % msg.chat.id]
+	if msg.from_user:
+		if msg.chat.id != msg.from_user.id:
+			result.append('user_id: %d' % msg.from_user.id)
+		result.append('user: ' + getDisplayUserHtml(msg.from_user))
+	if msg.chat.id < 0:
+		result.append('chat: ' + getDisplayChatHtml(msg.chat))
+	result.append('content: ' + msg.text_html_urled)
+	return ' '.join(result)
+
+def getOrigins(msg):
+	result = [msg.chat.id, msg.chat.username]
+	if msg.from_user:
+		result += [msg.from_user.id, msg.from_user.username]
+	return set([str(item) for item in result if item])
